@@ -22,7 +22,7 @@ class RecordLoaderMrOS(RecordLoaderSHHS):
 
         return path + "/" + recordId + "-nsrr.xml"
 
-    def groupBy(self, name: str, recordIds):
+    def groupBy(self, name: str, recordIds, metadata=None):
         groupedRecords = {}
         if name == "patient":
             for recordId in recordIds:
